@@ -94,7 +94,7 @@ public:  // methods
 
     void md5(eckit::MD5&) const;
 
-    void dump(std::ostream&, const char* cr = "\n", const char* tab = "\t") const;
+    void dump(std::ostream&, const char* cr = "\n", const char* tab = "\t", bool verb = true) const;
 
     void setValuesTyped(Type*, const std::vector<std::string>&);
 
@@ -106,6 +106,8 @@ public:  // methods
 
     MarsRequest extract(const std::string& category) const;
 
+    void erase(const std::string& param);
+
 public:  // static methods
     static MarsRequest parse(const std::string& s, bool strict = false);
     static std::vector<MarsRequest> parse(std::istream&, bool strict = false);
